v2.0.0
======

Dropped support for Python 3.5 and earlier.

v1.2.0
======

Ensure options such as readPreference, if included in the URL,
are honored by the MongoClient.

v1.1.0
======

Python 3 support.
Basic test suite and CI config.
